@@ -43,12 +43,13 @@ use Scalar::Util qw{ blessed looks_like_number };
 use PPIx::Regexp;
 use PPIx::Regexp::Constant qw{
     ARRAY_REF
+    INFINITY
     @CARP_NOT
 };
 use PPIx::Regexp::Tokenizer;
 use PPIx::Regexp::Util qw{ __choose_tokenizer_class __instance };
 
-our $VERSION = '0.081';
+our $VERSION = '0.086';
 
 use constant LOCATION_WIDTH	=> 19;
 
@@ -114,15 +115,6 @@ If true, this option causes the C<perl_version_introduced> and
 C<perl_version_removed> values associated with each object dumped to be
 displayed.
 
-=item postderef Boolean
-
-B<THIS ARGUMENT IS DEPRECATED>.  See L<DEPRECATION
-NOTICE|PPIx::QuoteLike/DEPRECATION NOTICE> in
-L<PPIx::QuoteLike|PPIx::QuoteLike> for the details.
-
-If true, postfix dereferences are recognized in code and interpolations.
-See the tokenizer's L<new()|PPIx::Regexp::Tokenizer/new> for details.
-
 =item ppi Boolean
 
 If true, any Perl code contained in the object will be dumped.
@@ -184,6 +176,10 @@ that the author reserves the right to change it without notice.
 
 The default is zero.
 
+=item width Boolean
+
+If true, this option causes a dump of the width of the object.
+
 =back
 
 If the thing to be dumped was a string, unrecognized arguments are
@@ -207,6 +203,7 @@ ignored.
 	test	=> 0,
 	tokens	=> 0,
 	verbose => 0,
+	width	=> 0,
     );
 
     sub new {
@@ -457,6 +454,36 @@ sub _format_modifiers_dump {
     return;
 }
 
+sub _format_width_dump {
+    my @arg = @_;
+    foreach ( @arg ) {
+	if ( defined ) {
+	    $_ == INFINITY
+		and $_ = q<'Inf'>;
+	} else {
+	    $_ = 'undef';
+	}
+    }
+    wantarray
+	and return @arg;
+    return join ', ', @arg;
+}
+
+sub _format_width_test {
+    my @arg = @_;
+    foreach ( @arg ) {
+	if ( defined ) {
+	    $_ == INFINITY
+		and $_ = 'INFINITY';
+	} else {
+	    $_ = 'undef';
+	}
+    }
+    wantarray
+	and return @arg;
+    return join ', ', @arg;
+}
+
 sub _tokens_test {
     my ( $self, $elem ) = @_;
 
@@ -540,6 +567,11 @@ sub PPIx::Regexp::Node::__PPIX_DUMPER__dump {
     $dumper->{locations}
 	and substr $rslt[0], 0, 0, ' ' x LOCATION_WIDTH;
 
+    if ( $dumper->{width} ) {
+	my $width = _format_width_dump( $self->width() );
+	$rslt[-1] .= "\t{ $width }";
+    }
+
     $dumper->{perl_version}
 	and $rslt[-1] .= "\t" . $dumper->_perl_version( $self );
 
@@ -577,6 +609,14 @@ sub PPIx::Regexp::Node::__PPIX_DUMPER__test {
 
     }
 
+    if ( $dumper->{width} ) {
+	my $raw = _format_width_test( $self->raw_width() );
+	my $width = _format_width_test( $self->width() );
+	push @rslt,
+	    "raw_width( $raw );",
+	    "width   ( $width );";
+    }
+
     if ( $dumper->{perl_version} ) {
 	foreach my $method ( qw{
 	    perl_version_introduced
@@ -633,6 +673,12 @@ sub _format_value {
 
 	$dumper->{perl_version}
 	    and push @rslt, $dumper->_perl_version( $self );
+
+	if ( $dumper->{width} ) {
+	    my $width = _format_width_dump( $self->width() );
+	    push @rslt, "{ $width }";
+	}
+
 	if ( $dumper->{verbose} ) {
 	    foreach my $method ( qw{ number name max_capture_number } ) {
 		$self->can( $method ) or next;
@@ -693,6 +739,15 @@ sub PPIx::Regexp::Structure::__PPIX_DUMPER__test {
 		$dumper->_safe( $self->$method() ) . ' );';
 	}
     }
+
+    if ( $dumper->{width} ) {
+	my $raw = _format_width_test( $self->raw_width() );
+	my $width = _format_width_test( $self->width() );
+	push @rslt,
+	    "raw_width( $raw );",
+	    "width   ( $width );";
+    }
+
     foreach my $method ( qw{ start type finish } ) {
 	my @eles = $self->$method();
 	push @rslt, 'choose  ( ' . $dumper->__nav(
@@ -761,6 +816,11 @@ sub PPIx::Regexp::Token::__PPIX_DUMPER__dump {
 	}
     }
 
+    if ( $dumper->{width} ) {
+	my $width = _format_width_dump( $self->width() );
+	push @rslt, "{ $width }";
+    }
+
     $dumper->{perl_version}
 	and push @rslt, $dumper->_perl_version( $self );
 
@@ -845,6 +905,14 @@ sub PPIx::Regexp::Token::__PPIX_DUMPER__test {
 	    }
 	}
 
+	if ( $dumper->{width} ) {
+	    my $raw = _format_width_test( $self->raw_width() );
+	    my $width = _format_width_test( $self->width() );
+	    push @rslt,
+		"raw_width( $raw );",
+		"width   ( $width );";
+	}
+
 	if ( $dumper->{verbose} ) {
 
 	    foreach my $method (
@@ -883,7 +951,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2021 by Thomas R. Wyant, III
+Copyright (C) 2009-2022 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
