@@ -43,7 +43,7 @@ use PPIx::Regexp::Constant qw{
 };
 use PPIx::Regexp::Util qw{ __instance };
 
-our $VERSION = '0.080';
+our $VERSION = '0.086';
 
 use constant TOKENIZER_ARGUMENT_REQUIRED => 1;
 
@@ -183,7 +183,7 @@ sub __PPIX_TOKENIZER__regexp {
 	push @tokens, $tokenizer->get_token();
 	
 	_treat_as_literal( $tokens[1] )
-	    or bless $tokens[0], TOKEN_LITERAL;
+	    or TOKEN_LITERAL->__PPIX_ELEM__rebless( $tokens[0] );
 	
 	return ( @tokens );
     }
@@ -208,7 +208,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2021 by Thomas R. Wyant, III
+Copyright (C) 2009-2022 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
